======
xradar
======


.. image:: https://img.shields.io/pypi/v/xradar.svg
        :target: https://pypi.python.org/pypi/xradar

.. image:: https://img.shields.io/travis/mgrover1/xradar.svg
        :target: https://travis-ci.com/mgrover1/xradar

.. image:: https://readthedocs.org/projects/xradar/badge/?version=latest
        :target: https://xradar.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Xradar includes all the tools to get your weather radar into the xarray data model.


* Free software: MIT license
* Documentation: https://xradar.readthedocs.io.


Features
--------

* TODO
